@@ -107,7 +107,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::checkout::Checkout;
             use checkout_core::payment::Payment;
             use checkout_core::payment::PaymentProcessor;
-            use checkout_core::payment::handlers::{process_handler, step_handler, callback_handler, cancel_handler};
+            use checkout_core::payment::handlers::{process_handler, step_handler, callback_handler, cancel_handler, get_handler as get_payment_handler};
             use checkout_core::customer::Contact;
             use checkout_core::customer::Address;
             use checkout_core::shipping::FulfillmentTypeSelection;
@@ -118,7 +118,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::context::{Context, ClientContext};
             use checkout_core::context::ClientContextProvider;
             use checkout_core::master_context::MasterContext;
-            use checkout_core::checkout::handlers::{create_handler, add_item_handler, remove_item_handler, confirm_items_handler, update_contact_handler, update_shipping_address_handler, update_fulfillment_type_handler, initiate_payment_handler, initiate_order_handler};
+            use checkout_core::checkout::handlers::{create_handler, add_item_handler, remove_item_handler, confirm_items_handler, update_contact_handler, update_shipping_address_handler, update_fulfillment_type_handler, initiate_payment_handler, initiate_order_handler, get_handler as get_checkout_handler};
 
             pub struct Config {
                 pub google_application_credentials: String,
@@ -266,6 +266,44 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 }
             }
 
+            #[endpoint {
+                method = GET,
+                path = "/checkout/{id}",
+            }]
+            pub async fn get_checkout_endpoint(
+                req_ctx: Arc<RequestContext<ServerContext>>,
+                path: Path<IdParam>,
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
+                let path_params = path.into_inner();
+                let mut ctx = req_ctx
+                    .context()
+                    .context_provider
+                    .new_context()
+                    .await
+                    .unwrap();
+
+                ctx.start_transaction().await.unwrap();
+                match get_checkout_handler(&mut ctx, &path_params.id).await {
+                    Ok(co) => {
+                        ctx.commit_transaction().await.unwrap();
+                        Ok(HttpResponseOk(co))
+                    }
+                    Err(err) => {
+                        ctx.abort_transaction().await.unwrap();
+                        Err(HttpError {
+                            status_code: StatusCode::BAD_REQUEST,
+                            error_code: Some(err.code.clone()),
+                            external_message: err.message.clone(),
+                            internal_message: err.message.clone(),
+                        })
+                    }
+                }
+            }
+
             #[endpoint {
                 method = PATCH,
                 path = "/checkout/{id}/add_item",
@@ -595,6 +633,44 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 correlation_id: String
             }
 
+            #[endpoint {
+                method = GET,
+                path = "/payment/{id}",
+            }]
+            pub async fn get_payment_endpoint(
+                req_ctx: Arc<RequestContext<ServerContext>>,
+                path: Path<IdParam>,
+            ) -> Result<HttpResponseOk<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>, HttpError> {
+                let path_params = path.into_inner();
+                let mut ctx = req_ctx
+                    .context()
+                    .context_provider
+                    .new_context()
+                    .await
+                    .unwrap();
+
+                ctx.start_transaction().await.unwrap();
+                match get_payment_handler(&mut ctx, &path_params.id).await {
+                    Ok(co) => {
+                        ctx.commit_transaction().await.unwrap();
+                        Ok(HttpResponseOk(co))
+                    }
+                    Err(err) => {
+                        ctx.abort_transaction().await.unwrap();
+                        Err(HttpError {
+                            status_code: StatusCode::BAD_REQUEST,
+                            error_code: Some(err.code.clone()),
+                            external_message: err.message.clone(),
+                            internal_message: err.message.clone(),
+                        })
+                    }
+                }
+            }
+
             #[endpoint {
                 method = PATCH,
                 path = "/payment/{id}/step",
@@ -735,6 +811,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             fn api_description() -> checkout_server::ApiDescription<Self::Context> {
                 let mut api = checkout_server::ApiDescription::new();
                 api.register(checkout_server::create_endpoint).unwrap();
+                api.register(checkout_server::get_checkout_endpoint).unwrap();
                 api.register(checkout_server::add_item_endpoint).unwrap();
                 api.register(checkout_server::remove_item_endpoint).unwrap();
                 api.register(checkout_server::confirm_items_endpoint).unwrap();
@@ -742,6 +819,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 api.register(checkout_server::update_shipping_address_endpoint).unwrap();
                 api.register(checkout_server::update_fulfillment_type_endpoint).unwrap();
                 api.register(checkout_server::initiate_payment_endpoint).unwrap();
+                api.register(checkout_server::get_payment_endpoint).unwrap();
                 api.register(checkout_server::step_payment_endpoint).unwrap();
                 api.register(checkout_server::callback_payment_endpoint).unwrap();
                 api.register(checkout_server::cancel_payment_endpoint).unwrap();
